@@ -40,7 +40,6 @@ public:
 
     void setLocationCode(const QString &locationCode);
     void setViewMode(int);
-    void setFont(QFont newFont);
     void setOrientation(Orientation o) { m_orientation = o; }
     /** resize the view **/
     void resizeView(const QSize &size);
@@ -56,7 +55,6 @@ signals: // Signals
 private:
     void initDock();
     void updateFont();
-    DCOPReply callDCOP( const QString &name );
 
     int m_mode;
     QString m_locationCode;
