@@ -18,13 +18,17 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
 ** Bug reports and questions can be sent to kde-devel@kde.org
 */
+
+#ifndef ASTRO_H
+#define ASTRO_H
+
 #include <time.h>
 
 extern "C" {
@@ -33,3 +37,6 @@ double kepler(double m, double ecc);
 void sunpos(double jd, int apparent, double *ra, double *dec, double *rv, double *slong);
 void projillum(short *wtab, int xdots, int ydots, double dec);
 }
+
+#endif // ASTRO_H
+
